# Демонстрационная программа "1288ПЛ1У_EM"

## Общие сведение

Программа предназначена для управления микросхемой (чтение/запись регистров) по интерфейсу SPI
через узел печатный ХХХ.Позволяет сохранять/загружать содержимое регистров в/из текстовых файлов, 
а также оформлять набор запросов к микросхеме в виде скрипта lua.

## Системные требования
### Персональный компьютер
* Процессор с тактовой частотой не менее 2 ГГц.
* Объем ОЗУ не менее 512 МБ.
* ХХ на жестком диске.
### Операционная система и ПО
* ОС Windows 7 и более новая, либо Linux с версией glibc не старше 2.23.
* libusb-1.0 (для Windows требуется установка libusbK, WinUSB или libusb-win32).

## Установка и запуск
* Распаковать архив с программой в рабочую директорию.
* Подключить плату ХХХ к ПК через разъем USB, подать питание на плату.
* Запустить <Рабочая директория>/mcolor19/bin/mcolor19

## Описание интерфейса программы
Функционал программы разделен на три вкладки - "Control", "Debug" и "Scripts". В верхней
части, общей для всех вкладок расположен селектор выбора системы счисления для представления 
содержимого регистров. В нижней общей части - органы управления для подачи сигналов pwdn и direct.
Далее приведено описание вкладок графического интерфейса программы.

### Control
Предназначен для установки делителей (целочисленных и дробных) и входной частоты Fref с целью 
получения требующейся частоты Fin (значения Fpfd и Fin рассчитываются, исходя из опорной частоты 
и установленных делителей и отображаются на вкладке). Значения делителей, а также полей регистров
Ctr1, Ctr2, Ctr3 записываются в микросхему при нажатии кнопки Set. Значения, записанные в окна 
вкладки, могут быть сохранены в текстовом файле нажатием кнопки Save. При нажатии кнопки Load, 
данные формы могут быть загружены из текстового файла. Состояние программируемого выхода OUT 
может быть отслежено выбором галочки OUT с частотой, указываемой в соответствующем окне, в 
милисекундах.

### Debug
Предоставляет доступ (чтение/запись) ко всем регистрам управления с побитовой индикацией полей.

### Script
Предоставляет функционал для редактирования, загрузки, сохранения и запуска скриптов.

## Скриптовый язык Lua
Программа содержит в себе интерпретатор языка Lua, который может быть использован для автоматизации
выполнения операций с микросхемой. Помимо стандартных функций языка, интерпретатор предоставляет 
пользователю класс Stand, предназначенный для операций обмена данными с регистрами микросхемы.

Перечислим методы класса Stand.

* new - создает новый объект класса Stand;
* vid_pid - возвращает Vendor ID, Product ID демонстрационной платы;
* fw_id - возвращает версию программного обеспечения демонстрационной платы;
* spi_capacity - возвращает разрядность SPI-интерфейса;
* get_out - возвращает состояние программируемого вывода OUT;
* set_pwdn(value) - устанавливает сигнал PWDN
* set_direct(value) - устанавливает сигнал DIRECT
* csleep(msec) - задержка в милисекундах
* write_register(address, data) - запись значения data в регистр с адресом address
* read_register(address) - возвращает значение, хранящееся в регистре с адресом address

Следующие функции осуществляют запись значения data в одноименный регистр.

* write_ref(data)
* write_lfm1(data)
* write_cint(data)
* write_lfm2(data)
* write_frac(data)
* write_lfm3(data)
* write_cmod(data)
* write_prw(data)
* write_ctr1(data)
* write_pra(data)
* write_ctr2(data)
* write_ctr3(data)

## Примеры работы с программой

### Пример1
*На вход подается частота 100 МГц. Необходимо получить Fin = 5 ГГц. На выходе OUT 
необходимо наблюдать признак захвата фазы.*

На вкладке Control необходимо выполнить следующие действия:

1. установить R = 2, N = 100, FRAC = MOD = 0;
2. установить OSEL = 0x3;
3. установить галочку OUT;
4. нажать кнопку Set.

Аналогичный результат выдаст следующий скрипт:

```lua
local stand = Stand.new();
stand:write_ref(2);
stand:write_cint(100);
stand:write_ctr1(0x600);
```

### Пример 2
*На вход подается частота 100 МГц. Необходимо установить режим ЛЧМ. 
Положим Fpfd = 100e3, Fin = 3.8 ГГц, SAWSTEP = 4000, период лчм = 10с,
развертка = 200e6 МГц.*

Для ручного задания режима перейдем на вкладку Debug и запишем:

* ```REF  ->	3e8```
* ```INT  ->	9470```
* ```FRAC ->	1```
* ```MOD  ->	fde8```
* ```CTR1 ->	40610```
* ```CTR2 ->	7```
* ```LFM1 ->	7ef40```
* ```LFM3 ->	4```
* ```LFM2 ->	fa0fa```

Аналогичный результат достигается выполнением скрипта:

```lua
local stand = Stand.new();
local f_ref = 100e+6;
local f_pfd = 100e+3;
local cint = 38000;
local frac = 1;
local cmod = 65000;
local sawstep = 4000;
local f_span = 200e+6; -- the span of the lfm
local r = f_ref / f_pfd;
local total_lfm_time = 10; -- The period of lfm
local fracinc = total_lfm_time * f_pfd / sawstep;
local dfrac = f_span * cmod / (sawstep * f_pfd) * 16;

stand:write_ref(math.floor(r));
stand:write_cint(cint);
stand:write_frac(frac);
stand:write_cmod(cmod);
stand:write_ctr1(0x40610);
stand:write_ctr2(0x7);
stand:write_lfm1(math.floor(dfrac));
stand:write_lfm3(0x4);
stand:write_lfm2((sawstep <<  8) | (math.floor(fracinc)));
```

Примеры скриптов расположены в директории /mcolor19/scripts.
